@@ -8,7 +8,7 @@ package Sumu::Perl::Modules;
 
 =head1 VERSION
 
-version 0.1.4
+version 0.1.5
 
 =head2 Strictures
     Enable strict and warnings
@@ -20,7 +20,7 @@ use warnings;
 =head2 VERSION
 =cut
 
-our $VERSION = '0.1.4';
+our $VERSION = '0.1.5';
 
 use parent qw(Exporter); 
 require Exporter; 
@@ -90,7 +90,7 @@ sub _extutils {
 
         $mods .= qq{<tr> 
             <td>$serial</td> 
-            <td> <a href="/perl/_modules/_dirs/$_" title="$_">$_</a> </td> 
+            <td> <a href="_dirs/$_" title="$_">$_</a> </td> 
             <td>$module_version</td> 
             <td>$module_files</td> 
             <td> $mod_dirs </td> 
@@ -123,6 +123,8 @@ sub _dirs  {
     my $module = $in{module};
     chomp $module; 
 
+    $module =~ s!\\!\/!g;
+
     my $inst = ExtUtils::Installed->new();
 
     #
@@ -153,7 +155,7 @@ sub _dirs  {
         my $cust_filename = $_;
         $cust_filename =~ s!^\/home\/$current_user!!g;
         #
-        $files .= qq{<li> <a href="/perl/_modules/_doc/$_" title="$cust_filename">$cust_filename</a> </li>};
+        $files .= qq{<li> <a href="_doc/$_" title="$cust_filename">$cust_filename</a> </li>};
     }
     $files .= qq{</ol>};
 
@@ -177,6 +179,8 @@ sub _doc {
     #
     my $module = $in{module};
         chomp $module;
+
+    $module =~ s!\\!\/!g;
     
     my @doc = `perldoc $module`;
 
@@ -188,7 +192,7 @@ sub _doc {
         $out .= qq{$_<br>};
     }
 
-    return($module, $out);
+    return ($module, $out);
 
     #
 
